"use client";

import { useState } from "react";
import { motion } from "framer-motion";

export function ResearchForm({ onSubmit }: { onSubmit?: (data: any) => void }) {
  const [loading, setLoading] = useState(false);
  const [researchTopic, setResearchTopic] = useState("");
  const [maxResults, setMaxResults] = useState(15);

  const handleSubmit = async (e: React.FormEvent) => {
    e.preventDefault();
    if (!researchTopic.trim()) return;
    
    setLoading(true);
    
    try {
      // 模拟API调用
      console.log("Submitted:", { researchTopic, maxResults });
      onSubmit?.({ researchTopic, maxResults });
      
      // 实际项目中这里会调用后端API
      // const response = await fetch("http://localhost:8000/api/research/process", {...});
    } catch (error) {
      console.error("Error:", error);
    } finally {
      setLoading(false);
    }
  };

  return (
    <form onSubmit={handleSubmit} className="space-y-6">
      <div className="space-y-2">
        <h2 className="text-xl font-semibold text-white/90">研究主题</h2>
        <p className="text-white/70 text-sm">
          输入您想探索的研究领域，AI将帮您分析相关文献
        </p>
        <textarea
          placeholder="例如：人工智能在医疗诊断中的应用"
          className="w-full min-h-[120px] rounded-xl p-4 bg-white/10 border border-white/20 text-white placeholder:text-white/40 focus:outline-none focus:ring-2 focus:ring-[var(--theme-accent)] focus:border-transparent shadow-inner transition-all duration-200"
          value={researchTopic}
          onChange={(e) => setResearchTopic(e.target.value)}
          disabled={loading}
        />
      </div>

      <div className="space-y-2">
        <div className="flex justify-between items-center">
          <label className="text-sm font-medium text-white/80">
            文献数量上限: {maxResults}
          </label>
          <span className="text-xs text-white/60">推荐: 10-20</span>
        </div>
        <input
          type="range"
          min={5}
          max={30}
          value={maxResults}
          onChange={(e) => setMaxResults(Number(e.target.value))}
          className="w-full accent-[var(--theme-accent)]"
          disabled={loading}
        />
      </div>

      <button 
        type="submit" 
        className="w-full py-4 px-6 rounded-xl bg-gradient-to-r from-[var(--theme-accent)] to-[var(--theme-highlight)] hover:brightness-110 text-white font-medium shadow-lg transform hover:scale-[1.02] transition-all duration-200"
        disabled={loading || !researchTopic.trim()}
      >
        {loading ? (
          <span className="flex items-center justify-center">
            <svg className="animate-spin -ml-1 mr-2 h-5 w-5 text-white" xmlns="http://www.w3.org/2000/svg" fill="none" viewBox="0 0 24 24">
              <circle className="opacity-25" cx="12" cy="12" r="10" stroke="currentColor" strokeWidth="4"></circle>
              <path className="opacity-75" fill="currentColor" d="M4 12a8 8 0 018-8V0C5.373 0 0 5.373 0 12h4zm2 5.291A7.962 7.962 0 014 12H0c0 3.042 1.135 5.824 3 7.938l3-2.647z"></path>
            </svg>
            处理中...
          </span>
        ) : (
          "开始研究"
        )}
      </button>
    </form>
  );
}
